==> ukui-menu_4.10.2.11.orig.tar.gz: ukui-menu-4.10.2.11/translations/ukui-menu_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>FavoriteExtension</name>
    <message>
        <source>Enable editing mode</source>
        <translation>تۈركۈملەپ تەھرىرلەش ئەندىزىسىنى ئىشقا كىرىشتۈرۈش</translation>
    </message>
    <message>
        <source>Remove all favorite apps</source>
        <translation>بارلىق يىغىپ ساقلاش قوللىنىلىشىنى بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>FullScreenAppList</name>
    <message>
        <source>Favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
    <message>
        <source>Enable editing mode</source>
        <translation>تۈركۈملەپ تەھرىرلەش ئەندىزىسىنى ئىشقا كىرىشتۈرۈش</translation>
    </message>
    <message>
        <source>Remove all favorite apps</source>
        <translation>بارلىق يىغىپ ساقلاش قوللىنىلىشىنى بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>FullScreenHeader</name>
    <message>
        <source>Contract</source>
        <translation>قىسقىراش</translation>
    </message>
</context>
<context>
    <name>PluginSelectButton</name>
    <message>
        <source>Letter Sort</source>
        <translation>ھەرپ رەتكە تىزىش</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>ئىقتىدار تەرتىپى</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Add to desktop shortcuts</source>
        <translation>ئۈستەل يۈزىگە قوشۇش تېز ئۇسۇل</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>يۈكنى چۈشۈرۈش</translation>
    </message>
    <message>
        <source>Remove from folder</source>
        <translation>قوللىنىشچان گۇرۇپپىدىن چىقىرىۋەتمەك</translation>
    </message>
    <message>
        <source>Add to folder</source>
        <translation>قوللىنىش گۇرۇپپىسىغا قوشۇلماق</translation>
    </message>
    <message>
        <source>Dissolve folder</source>
        <translation>تارقىتىۋېتىش قوللىنىش گۇرۇپپىسى</translation>
    </message>
    <message>
        <source>Add to &quot;%1&quot;</source>
        <translation>&quot;%1&quot; قوشۇلدى</translation>
    </message>
    <message>
        <source>Show ukui-menu.</source>
        <translation>باشلىنىش تاماق تىزىملىكىنى كۆرسىتىش</translation>
    </message>
    <message>
        <source>Quit ukui-menu.</source>
        <translation>باشلىنىش تىزىملىكىدىن چېكىنىپ چىقماق</translation>
    </message>
    <message>
        <source>Fix to favorite</source>
        <translation>يىغىپ ساقلىغىچە مۇقىملاشتۇرۇش</translation>
    </message>
    <message>
        <source>Remove from favorite</source>
        <translation>يىغىپ ساقلاش قىسقۇچتىن مۇقىملىقنى ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Remove from taskbar</source>
        <translation>ۋەزىپە ئىستونىدىن مۇقىملىقنى ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Add to taskbar</source>
        <translation>ۋەزىپە كاتەكچىسىگە مۇقىملاشتۇرۇش</translation>
    </message>
    <message>
        <source>Fixed to all applications</source>
        <translation>بارلىق قوللىنىشچانلىققا مۇقىملاشتۇرۇش</translation>
    </message>
    <message>
        <source>Unfixed from all applications</source>
        <translation>بارلىق قوللىنىشتىن مۇقىملىقنى ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Create a new folder</source>
        <translation>يېڭىدىن قوللىنىش گۇرۇپپىسى قۇرما</translation>
    </message>
    <message>
        <source>Remove from List</source>
        <translation>تىزىملىكتىن چىقىرىۋەتمەك</translation>
    </message>
</context>
<context>
    <name>SearchInputBar</name>
    <message>
        <source>Search App</source>
        <translation>ئىزدەش قوللىنىش</translation>
    </message>
</context>
<context>
    <name>Sidebar</name>
    <message>
        <source>Expand</source>
        <translation>قانات يايدۇرۇلدى</translation>
    </message>
    <message>
        <source>Contract</source>
        <translation>قىسقىراش</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>كومپيۇتېر</translation>
    </message>
    <message>
        <source>Control center</source>
        <translation>كونترول قىلىش ئېكرانى</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AllAppDataProvider</name>
    <message>
        <source>All</source>
        <translation>بارلىق قوللىنىشچانلىق</translation>
    </message>
    <message>
        <source>All applications</source>
        <translatorcomment>所有应用</translatorcomment>
        <translation>بارلىق قوللىنىشچانلىق</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryModel</name>
    <message>
        <source>Audio</source>
        <translation>ئاۋازلىق چاستوتا</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>ئاۋاز ۋە كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>مائارىپ</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>ئويۇن</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>گىرافىك</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ئىشخانا</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>ئىلىم -پەن</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەسىس قىلىش</translation>
    </message>
    <message>
        <source>System</source>
        <translation>سىستىما</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>قوللىنىشچان پروگرامما</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>باشقىسى</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryPlugin</name>
    <message>
        <source>Category</source>
        <translatorcomment>功能排序</translatorcomment>
        <translation>ئىقتىدار تەرتىپى</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>ئاۋازلىق چاستوتا</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>ئاۋاز ۋە كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>مائارىپ</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>ئويۇن</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>گىرافىك</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ئىشخانا</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>ئىلىم -پەن</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەسىس قىلىش</translation>
    </message>
    <message>
        <source>System</source>
        <translation>سىستىما</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>قوللىنىشچان پروگرامما</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>باشقىسى</translation>
    </message>
    <message>
        <source>Open Function Sort Menu</source>
        <translation>ئىقتىدار رەتكە تىزىش تىزىملىكىنى ئېچىش</translation>
    </message>
    <message>
        <source>Letter Sort</source>
        <translation>ھەرپ رەتكە تىزىش</translation>
    </message>
    <message>
        <source>Recently Installed</source>
        <translation>ئەڭ يېڭى قۇراشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>يىڭى ھۆججەت قىسقۇچ 1%</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppLetterSortPlugin</name>
    <message>
        <source>Letter Sort</source>
        <translation>ھەرپ رەتكە تىزىش</translation>
    </message>
    <message>
        <source>Open Letter Sort Menu</source>
        <translation>ھەرپ تەرتىپى تىزىملىكىنى ئېچىش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppSearchPlugin</name>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteExtension</name>
    <message>
        <source>Favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>يىڭى ھۆججەت قىسقۇچ 1%</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteWidget</name>
    <message>
        <source>Favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
    <message>
        <source>favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::PowerButton</name>
    <message>
        <source>power</source>
        <translation>توك مەنبەسى</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>خېرىدار ئالماشتۇرماق</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇيقۇ</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ئۇيقۇ</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation>ئېكراننى قۇلۇپلاش</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation>بىكار قىلىۋەتمەك</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتىدىن قوزغىتىش</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>تېلېفوننى ئېتىۋېتىش</translation>
    </message>
    <message>
        <source>&lt;p&gt;The computer remains on but consumes less power, and the applications will remain open. You can quickly wake up the computer and return to the state you left&lt;/p&gt;</source>
        <translation>&lt;p&gt;كومپيۇتېر ئېچىلىش ھالىتىنى ساقلايدۇ،لىكىن توك سەرپىياتى ئاز قوللىنىش ئىزچىل ئېچىلىش ھالىتىنى ساقلاپ كەلدى، كومپيۇتېرنى تېز سۈرئەتتە ئويغىتىدۇ ھەمدە ئايرىلىش ھالىتىڭىزگە قايتىدۇ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;The current user logs out of the system, ending their session and returning to the login screen&lt;/p&gt;</source>
        <translation>&lt;p&gt;نۆۋەتتە ئابونتلار سىستېمىدىن بىكار قىلىنىپ، سۆزلىشىشنى ئاخىرلاشتۇردى ھەمدە تىزىملىتىش كۆرۈنۈشىگە قايتىدۇ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, turn off the computer, and then turn it back on&lt;/p&gt;</source>
        <translation>&lt;p&gt;بارلىق قوللىنىشچان نۇقتىلارنى ئېتىپ، كومپيۇتېرنى ئېتىۋېتىڭ، ئاندىن كومپيۇتېرنى قايتىدىن ئېچىڭ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, and then turn off the computer&lt;/p&gt;</source>
        <translation>&lt;p&gt;بارلىق قوللىنىشچان نۇقتىنى تاقاش، ئاندىن كومپيۇتېرنى ئېتىڭ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Turn off the computer, but the applications will remain open. When you turn on the computer again, you can return to the state you were in before&lt;/p&gt;</source>
        <translation>&lt;p&gt;كومپيۇتېرنى ئېتىۋېتىڭ، لېكىن قوللىنىشچان ھالەتنى ئىزچىل ساقلاپ قالىدۇ كومپىيوتىرنى ئاچقاندا ،سىز ئايرىلغان ھالەتكە قايتقىلى بولىدۇ&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::RecentlyInstalledModel</name>
    <message>
        <source>Recently Installed</source>
        <translation>ئەڭ يېڭى قۇراشتۇرۇش</translation>
    </message>
</context>
</TS>

==> ukui-menu_5.0.0.1.orig.tar.gz: ukui-menu-5.0.0.1/translations/ukui-menu_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>FavoriteExtension</name>
    <message>
        <source>Enable editing mode</source>
        <translation>تۈركۈملەپ تەھرىرلەش ئەندىزىسىنى ئىشقا كىرىشتۈرۈش</translation>
    </message>
    <message>
        <source>Remove all favorite apps</source>
        <translation>بارلىق يىغىپ ساقلاش قوللىنىلىشىنى بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>FullScreenAppList</name>
    <message>
        <source>Favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
    <message>
        <source>Enable editing mode</source>
        <translation>تۈركۈملەپ تەھرىرلەش ئەندىزىسىنى ئىشقا كىرىشتۈرۈش</translation>
    </message>
    <message>
        <source>Remove all favorite apps</source>
        <translation>بارلىق يىغىپ ساقلاش قوللىنىلىشىنى بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>FullScreenHeader</name>
    <message>
        <source>Contract</source>
        <translation>قىسقىراش</translation>
    </message>
</context>
<context>
    <name>PluginSelectButton</name>
    <message>
        <source>Letter Sort</source>
        <translation>ھەرپ رەتكە تىزىش</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>ئىقتىدار تەرتىپى</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Add to desktop shortcuts</source>
        <translation>ئۈستەل يۈزىگە قوشۇش تېز ئۇسۇل</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>يۈكنى چۈشۈرۈش</translation>
    </message>
    <message>
        <source>Remove from folder</source>
        <translation>قوللىنىشچان گۇرۇپپىدىن چىقىرىۋەتمەك</translation>
    </message>
    <message>
        <source>Add to folder</source>
        <translation>قوللىنىش گۇرۇپپىسىغا قوشۇلماق</translation>
    </message>
    <message>
        <source>Dissolve folder</source>
        <translation>تارقىتىۋېتىش قوللىنىش گۇرۇپپىسى</translation>
    </message>
    <message>
        <source>Add to &quot;%1&quot;</source>
        <translation>&quot;%1&quot; قوشۇلدى</translation>
    </message>
    <message>
        <source>Show ukui-menu.</source>
        <translation>باشلىنىش تاماق تىزىملىكىنى كۆرسىتىش</translation>
    </message>
    <message>
        <source>Quit ukui-menu.</source>
        <translation>باشلىنىش تىزىملىكىدىن چېكىنىپ چىقماق</translation>
    </message>
    <message>
        <source>Fix to favorite</source>
        <translation>يىغىپ ساقلىغۇچە مۇقىملاشتۇرۇش</translation>
    </message>
    <message>
        <source>Remove from favorite</source>
        <translation>يىغىپ ساقلاش قىسقۇچتىن مۇقىملىقنى ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Remove from taskbar</source>
        <translation>ۋەزىپە ئىستونىدىن مۇقىملىقنى ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Add to taskbar</source>
        <translation>ۋەزىپە كاتەكچىسىگە مۇقىملاشتۇرۇش</translation>
    </message>
    <message>
        <source>Fixed to all applications</source>
        <translation>بارلىق قوللىنىشچانلىققا مۇقىملاشتۇرۇش</translation>
    </message>
    <message>
        <source>Unfixed from all applications</source>
        <translation>بارلىق قوللىنىشتىن مۇقىملىقنى ئەمەلدىن قالدۇرۇش</translation>
    </message>
    <message>
        <source>Create a new folder</source>
        <translation>يېڭىدىن قوللىنىش گۇرۇپپىسى قۇرما</translation>
    </message>
    <message>
        <source>Remove from List</source>
        <translation>تىزىملىكتىن چىقىرىۋەتمەك</translation>
    </message>
</context>
<context>
    <name>SearchInputBar</name>
    <message>
        <source>Search App</source>
        <translation>ئىزدەش قوللىنىش</translation>
    </message>
</context>
<context>
    <name>Sidebar</name>
    <message>
        <source>Expand</source>
        <translation>قانات يايدۇرۇلدى</translation>
    </message>
    <message>
        <source>Contract</source>
        <translation>قىسقىراش</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>كومپيۇتېر</translation>
    </message>
    <message>
        <source>Control center</source>
        <translation>كونترول قىلىش ئېكرانى</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AllAppDataProvider</name>
    <message>
        <source>All</source>
        <translation>بارلىق قوللىنىشچانلىق</translation>
    </message>
    <message>
        <source>All applications</source>
        <translatorcomment>所有应用</translatorcomment>
        <translation>بارلىق قوللىنىشچانلىق</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryModel</name>
    <message>
        <source>Audio</source>
        <translation>ئاۋازلىق چاستوتا</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>ئاۋاز ۋە كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>مائارىپ</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>ئويۇن</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>گىرافىك</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ئىشخانا</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>ئىلىم -پەن</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەسىس قىلىش</translation>
    </message>
    <message>
        <source>System</source>
        <translation>سىستېما</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>قوللىنىشچان پىروگرامما</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>باشقىسى</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryPlugin</name>
    <message>
        <source>Category</source>
        <translatorcomment>功能排序</translatorcomment>
        <translation>ئىقتىدار تەرتىپى</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>ئاۋازلىق چاستوتا</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>ئاۋاز ۋە كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>مائارىپ</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>ئويۇن</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>گىرافىك</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>ئىشخانا</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>ئىلىم -پەن</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەسىس قىلىش</translation>
    </message>
    <message>
        <source>System</source>
        <translation>سىستېما</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>قوللىنىشچان پىروگرامما</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>كۆرۈنمە چاستوتا</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>باشقىسى</translation>
    </message>
    <message>
        <source>Open Function Sort Menu</source>
        <translation>ئىقتىدار رەتكە تىزىش تىزىملىكىنى ئېچىش</translation>
    </message>
    <message>
        <source>Letter Sort</source>
        <translation>ھەرپ رەتكە تىزىش</translation>
    </message>
    <message>
        <source>Recently Installed</source>
        <translation>ئەڭ يېڭى قۇراشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>يېڭى ھۆججەت قىسقۇچ 1%</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppLetterSortPlugin</name>
    <message>
        <source>Letter Sort</source>
        <translation>ھەرپ رەتكە تىزىش</translation>
    </message>
    <message>
        <source>Open Letter Sort Menu</source>
        <translation>ھەرپ تەرتىپى تىزىملىكىنى ئېچىش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppSearchPlugin</name>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteExtension</name>
    <message>
        <source>Favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>يېڭى ھۆججەت قىسقۇچ 1%</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteWidget</name>
    <message>
        <source>Favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
    <message>
        <source>favorite</source>
        <translation>يىغىپ ساقلاش</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::PowerButton</name>
    <message>
        <source>power</source>
        <translation>توك مەنبەسى</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>خېرىدار ئالماشتۇرماق</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇيقۇ</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ئۇيقۇ</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation>ئېكراننى قۇلۇپلاش</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation>بىكار قىلىۋەتمەك</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتىدىن قوزغىتىش</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>تېلېفوننى ئېتىۋېتىش</translation>
    </message>
    <message>
        <source>&lt;p&gt;The computer remains on but consumes less power, and the applications will remain open. You can quickly wake up the computer and return to the state you left&lt;/p&gt;</source>
        <translation>&lt;p&gt;كومپيۇتېر ئېچىلىش ھالىتىنى ساقلايدۇ،لىكىن توك سەرپىياتى ئاز قوللىنىش ئىزچىل ئېچىلىش ھالىتىنى ساقلاپ كەلدى، كومپيۇتېرنى تېز سۈرئەتتە ئويغىتىدۇ ھەمدە ئايرىلىش ھالىتىڭىزگە قايتىدۇ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;The current user logs out of the system, ending their session and returning to the login screen&lt;/p&gt;</source>
        <translation>&lt;p&gt;نۆۋەتتە ئابونتلار سىستېمىدىن بىكار قىلىنىپ، سۆزلىشىشنى ئاخىرلاشتۇردى ھەمدە تىزىملىتىش كۆرۈنۈشىگە قايتىدۇ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, turn off the computer, and then turn it back on&lt;/p&gt;</source>
        <translation>&lt;p&gt;بارلىق قوللىنىشچان نۇقتىلارنى ئېتىپ، كومپيۇتېرنى ئېتىۋېتىڭ، ئاندىن كومپيۇتېرنى قايتىدىن ئېچىڭ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, and then turn off the computer&lt;/p&gt;</source>
        <translation>&lt;p&gt;بارلىق قوللىنىشچان نۇقتىنى تاقاش، ئاندىن كومپيۇتېرنى ئېتىڭ&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Turn off the computer, but the applications will remain open. When you turn on the computer again, you can return to the state you were in before&lt;/p&gt;</source>
        <translation>&lt;p&gt;كومپيۇتېرنى ئېتىۋېتىڭ، لېكىن قوللىنىشچان ھالەتنى ئىزچىل ساقلاپ قالىدۇ كومپيۇتېرنى ئاچقاندا ،سىز ئايرىلغان ھالەتكە قايتقىلى بولىدۇ&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::RecentlyInstalledModel</name>
    <message>
        <source>Recently Installed</source>
        <translation>ئەڭ يېڭى قۇراشتۇرۇش</translation>
    </message>
</context>
</TS>
